Documentation
¶
Index ¶
- Variables
- func IsFunc(value sobek.Value) bool
- func IsPromise(value sobek.Value) bool
- func IsTypedArray(rt *sobek.Runtime, value sobek.Value) bool
- func IsUint8Array(rt *sobek.Runtime, value sobek.Value) bool
- func Iterator(rt *sobek.Runtime, seq iter.Seq[any]) *sobek.Object
- func New(rt *sobek.Runtime, name string, args ...sobek.Value) *sobek.Object
Constants ¶
This section is empty.
Variables ¶
var ( TypeFunc = reflect.TypeOf((func(sobek.FunctionCall) sobek.Value)(nil)) TypeInt = reflect.TypeOf(int64(0)) TypeFloat = reflect.TypeOf(0.0) TypeString = reflect.TypeOf("") TypeBytes = reflect.TypeOf(([]byte)(nil)) TypeArrayBuffer = reflect.TypeOf(sobek.ArrayBuffer{}) TypeError = reflect.TypeOf((*error)(nil)).Elem() TypePromise = reflect.TypeOf((*sobek.Promise)(nil)) TypeNil = reflect.TypeOf(nil) )
Functions ¶
func IsTypedArray ¶
IsTypedArray returns true if the value is a TypedArray.
func IsUint8Array ¶
IsUint8Array returns true if the value is a Uint8Array.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.