Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
TypeURLSearchParams = reflect.TypeOf((*urlSearchParams)(nil))
)
Functions ¶
This section is empty.
Types ¶
type URL ¶
type URL struct{}
URL is a component of the URL standard, which defines what constitutes a valid Uniform Resource Locator and the API that accesses and manipulates URLs. The URL standard also defines concepts such as domains, hosts, and IP addresses, and also attempts to describe in a standard way the legacy application/x-www-form-urlencoded MIME type used to submit web forms' contents as a set of key/value pairs. https://developer.mozilla.org/en-US/docs/Web/API/URL_API
type URLSearchParams ¶
type URLSearchParams struct{}
URLSearchParams defines utility methods to work with the query string of a URL, which can be sent using the http() method and encoding type were set to "application/x-www-form-url". https://developer.mozilla.org/en-US/docs/Web/API/URLSearchParams